@@ -20,9 +20,9 @@ import numpy as np
 from pymongo import MongoClient
 from bson.objectid import ObjectId
 
-from dataset_serialize_pb2 import DsetFile
-from log_obj import log, CONFIG
-from file_access import FileAccess
+from eyeflow_sdk.dataset_serialize_pb2 import DsetFile
+from eyeflow_sdk.log_obj import log, CONFIG
+from eyeflow_sdk.file_access import FileAccess
 #----------------------------------------------------------------------------------------------------------------------------------
 
 def slugify(value):
