@@ -13,8 +13,8 @@ import random
 from bson import ObjectId
 import cv2
 
-from file_access import FileAccess
-from log_obj import log
+from eyeflow_sdk.file_access import FileAccess
+from eyeflow_sdk.log_obj import log
 #----------------------------------------------------------------------------------------------------------------------------------
 
 MAX_EXTRACT_FILES = 800
